# zxvcv.cmdutil
Toolbox for other projects.

# Build
```
tox -e build
```

# Publish
```
tox -e publish -- -u <username> -p <password>
```

publish on testpypi
```
tox -e publish -- --repository testpypi -u <username> -p <password>
